@@ -14,21 +14,23 @@ either the contents of standard out the value of an expression itself.
 
 A doctest that uses stdout might look like this
 
->>> print('We expect this exact string')
-We expect this exact string
+.. code:: python
+
+    >>> print('We expect this exact string')
+    We expect this exact string
 
 A doctest that uses a raw expression might look like this
 
->>> def foo():
->>>     return 3
->>> foo()
-3
+.. code:: python
+
+    >>> def foo():
+    >>>     return 3
+    >>> foo()
+    3
 
 In most cases it is best to use stdout to write your got-want tests because it
 is easier to control strings sent to stdout than it is to control the
 representation of expression-based "got-strings".
-
-
 """
 import re
 import difflib
@@ -634,7 +636,7 @@ def remove_blankline_marker(text):
         '\n{marker}', '{marker}']).format(
             marker=BLANKLINE_MARKER, pos_lb=pos_lb)
     # blankline_pattern = r'(?<=\n)[ ]*{}\n?'.format(re.escape(BLANKLINE_MARKER))
-    new_text = re.sub(blankline_pattern, '\n', text, re.MULTILINE)
+    new_text = re.sub(blankline_pattern, '\n', text, flags=re.MULTILINE)
     return new_text
 
 
